@@ -6,12 +6,12 @@ from django.utils.safestring import mark_safe
 class ColorPickerWidget(forms.TextInput):
     class Media:
         css = {
-            "all": ("paintstore/css/colorpicker.css",)
+            "all": ("%s/%s" % (settings.STATIC_URL, "paintstore/css/colorpicker.css"),)
         }
-        
+
         js  = (
-            "https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.js", 
-            "paintstore/colorpicker.js",
+            ("%s/%s" % (settings.STATIC_URL, "paintstore/jquery_1.7.2.js")),
+            ("%s/%s" % (settings.STATIC_URL, "paintstore/colorpicker.js"))
         )
 
     input_type = 'colorpicker'
@@ -35,4 +35,4 @@ class ColorPickerWidget(forms.TextInput):
                     """ % ("id_%s" % name,)
 
         super_render = super(ColorPickerWidget, self).render(name, value, attrs)
-        return mark_safe(u"%s%s" % (super_render, script))
\ No newline at end of file
+        return mark_safe(u"%s%s" % (super_render, script))
